Model attribution:

`yf23` is from: https://www.thingiverse.com/thing:3322220

`talon` is from: https://www.thingiverse.com/thing:4726493/

Both have been modified to be of unit length, with the origin approximately at the CG.
